@@ -14,8 +14,14 @@
 
 """MOSEC is a machine learning model serving framework."""
 
-import logging
-
+from .errors import (
+    ClientError,
+    DecodingError,
+    EncodingError,
+    ServerError,
+    ValidationError,
+)
+from .log import get_logger
 from .server import Server
 from .worker import Worker
 
@@ -26,7 +32,13 @@ except ImportError:
 
     __version__ = get_version(root="..", relative_to=__file__)
 
-__all__ = ["Server", "Worker"]
-
-# setup library logging
-logging.getLogger(__name__).addHandler(logging.NullHandler())
+__all__ = [
+    "Server",
+    "Worker",
+    "ServerError",
+    "ClientError",
+    "ValidationError",
+    "EncodingError",
+    "DecodingError",
+    "get_logger",
+]
